# Changelog

All notable changes to this project will be documented in this file.

## [unreleased]

### 🚀 Features

- *(cli)* Serve

### 🚜 Refactor

- *(fastapi)* Add a fastapi server with a nats plugin

<!-- generated by git-cliff -->
